@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtPositioning module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include <private/qpositioningquickglobal_p.h>
 #include <QtPositioningQuick/private/qquickgeocoordinateanimation_p.h>
@@ -45,7 +9,8 @@
 QT_BEGIN_NAMESPACE
 
 /*!
-    \qmlbasictype coordinate
+    \qmlvaluetype coordinate
+    \ingroup qmlvaluetypes
     \inqmlmodule QtPositioning
     \ingroup qml-QtPositioning5-basictypes
     \since 5.2
@@ -202,7 +167,8 @@ QT_BEGIN_NAMESPACE
 */
 
 /*!
-    \qmlbasictype geoshape
+    \qmlvaluetype geoshape
+    \ingroup qmlvaluetypes
     \inqmlmodule QtPositioning
     \ingroup qml-QtPositioning5-basictypes
     \since 5.2
@@ -304,7 +270,8 @@ QT_BEGIN_NAMESPACE
 */
 
 /*!
-    \qmlbasictype georectangle
+    \qmlvaluetype georectangle
+    \ingroup qmlvaluetypes
     \inqmlmodule QtPositioning
     \ingroup qml-QtPositioning5-basictypes
     \since 5.2
@@ -420,7 +387,8 @@ QT_BEGIN_NAMESPACE
 */
 
 /*!
-    \qmlbasictype geocircle
+    \qmlvaluetype geocircle
+    \ingroup qmlvaluetypes
     \inqmlmodule QtPositioning
     \ingroup qml-QtPositioning5-basictypes
     \since 5.2
@@ -473,7 +441,8 @@ QT_BEGIN_NAMESPACE
 */
 
 /*!
-    \qmlbasictype geopath
+    \qmlvaluetype geopath
+    \ingroup qmlvaluetypes
     \inqmlmodule QtPositioning
     \ingroup qml-QtPositioning5-basictypes
     \since 5.9
@@ -505,7 +474,8 @@ QT_BEGIN_NAMESPACE
 */
 
 /*!
-   \qmlbasictype geopolygon
+   \qmlvaluetype geopolygon
+   \ingroup qmlvaluetypes
    \inqmlmodule QtPositioning
    \ingroup qml-QtPositioning5-basictypes
    \since 5.10
